@@ -543,9 +543,9 @@ module.exports = function(hg) {
 				if (!item.date) {
 					return false;
 				}
-				var dt = new Date(item.date);
+				var dt = new Date(item.date); 
 				if (/^\d+$/.test(args.timeframe)) {
-					return dt.getFullYear() == args.timeframe;
+					return dt.getUTCFullYear() == args.timeframe;
 				}
 
 				var diff = now - dt.getTime()
@@ -702,7 +702,7 @@ module.exports = function(hg) {
 		var maxContributions = -Infinity;
 		// figure out metadata about the whole result set before we trim down to the current page
 		rv.results.items.forEach(function(item) {
-				if (item.domain == 'members') {
+			if (item.domain == 'members') {
 				var count = 0;
 				for (var k in item.contributions) {
 					count += item.contributions[k];
@@ -726,6 +726,20 @@ module.exports = function(hg) {
 			.filter(isSelected)
 			// and figure out sorting of the things that are actually relevant
 			.adjustWeights(function(item) {
+				['tag', 'contributor', 'group'].forEach(function(type) {
+					var key = type + '_ids';
+					if (item[key]) {
+						item[key].forEach(function(id) {
+							if (rv[type + 's'][id]) {
+								++rv[type + 's'][id][1];
+							}
+							else {
+								rv[type + 's'][id] = [null, 1]
+							}
+						});
+					}
+				});
+				/*
 				var rels = {'tag': 'aliases', 'contributor': 'members', 'group': 'groups'};
 				for (var type in rels) {
 					var key = type + '_ids';
@@ -740,10 +754,11 @@ module.exports = function(hg) {
 						});
 					}
 				}
+				*/
 
 				if (item.date) {
-					var dt = new Date(item.date), 
-					    yr = dt.getFullYear(),
+					var dt = new Date(item.date),
+					    yr = dt.getUTCFullYear(),
 					  diff = now - dt.getTime()
 					;
 
@@ -755,7 +770,7 @@ module.exports = function(hg) {
 						++rv.timeframe[yr][1];
 					}
 					if (diff <= day) {
-						++rv.timeframe['day'][1];
+						++rv.timeframe['day'][1];	
 					}
 					else if (diff <= week) {
 						++rv.timeframe['week'][1];
@@ -781,17 +796,29 @@ module.exports = function(hg) {
 			rv.timeframe = [];
 		}
 		
-		var facets = {'tags': 'aliases', 'inGroup': 'groups', 'users': 'members'};
+		// rv now contains a bunch of {id: [null, # of items in result]} entries for metadata
+		// we look them now to fill them in so they have {id: ['Nice Title', # of items]} instead
+		var facets = {'tag': 'tags', 'group': 'groups', 'user': 'contributors'};
 		for (var k in facets) {
-			var rk = k == 'inGroup' ? 'groups': k == 'users' ? 'contributors' : k;
-			args[k].forEach(function(id) {
-				if (!rv[rk][id]) {
-					var item = hg.select(facets[k], k == 'tags' ? 'tag:' + id : id).use();
-					if (item.items.length) {
-						rv[rk][id] = [item.items[0].title, -1];
-					}
+			// it's possible that some metadata items need to be included even though they were 
+			// responsible for no result items, when the user has selected them as a facet for
+			// a query that returns no results. they need to show up so that the client gives
+			// the user an opportunity to de-select the facet
+			var rk = k == 'user' ?'users' : facets[k];
+			for (var id in args[rk]) {
+				if (!rv[facets[k]][id]) {
+					rv[facets[k]][id] = [null, -1];
 				}
-			});
+			}
+			// look up titles
+			for (var id in rv[facets[k]]) {
+				var item = hg.select('aliases', k + ':' + id).use();
+				// item is often unavailable during testing if I limit the number of entries to
+				// pull in. with a full data set, however, it should always be found
+				if (item.items.length) {
+					rv[facets[k]][id] = [item.items[0].title, rv[facets[k]][id][1]];
+				}
+			}
 		}
 		
 		rv.results = rv.results
